# generated by datamodel-codegen:
#   filename:  sensors.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class Sensors(BaseModel):
    """
    Sensors
    """

    class Config:
        extra = Extra.allow

    id: Optional[str] = Field(None, description="Event ID")
    last_updated: Optional[dict[str, float]] = Field(None, description="Last updated")
